@@ -1,10 +1,7 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "simplemenu.h"
@@ -161,4 +158,4 @@ void SimpleMenu::setupController(Controller* controller, Entity* old_opponent, S
     controller->start(sea);
 }
 
-
+#include "moc_simplemenu.cpp"
